California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 023 - AUTHORIZES STATE REGULATION OF KIDNEY DIALYSIS CLINICS. ESTABLISHES MINIMUM STAFFING AND OTHER REQUIREMENTS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1373047 | SERVICE EMPLOYEES INTERNATIONAL UNION, UNITED HEALTHCARE WORKERS WEST (NONPROFIT 501 (C)(5)) - YES ON 23 - CALIFORNIANS FOR KIDNEY DIALYSIS PATIENT PROTECTION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1424580 | NO ON 23 - STOP THE DANGEROUS & COSTLY DIALYSIS PROPOSITION, A COALITION OF DIALYSIS PROVIDERS, NURSES, DOCTORS AND PATIENTS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1398274 | YES ON 23 - CALIFORNIANS FOR KIDNEY DIALYSIS PATIENT PROTECTION, SPONSORED BY SERVICE EMPLOYEES INTERNATIONAL UNION - UNITED HEALTHCARE WORKERS WEST | SUPPORT